A simple implementation of a user GUI for [Neuroimage Denoiser](https://github.com/s-weissbach/neuroimage_denoiser) for iternal use in the AG Heine. All credits of the program itself go to
**Neuroimage Denoiser for removing noise from transient fluorescent signals in functional imaging.**
Stephan Weissbach, Jonas Milkovits, Michela Borghi, Carolina Amaral, Abderazzaq El Khallouqi, Susanne Gerber, Martin Heine
*bioRxiv* 2024.06.08.598061; doi: https://doi.org/10.1101/2024.06.08.598061